/**
  *  \file client/dialogs/labeldlg.cc
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/dialogs/labeldlg.h"
#include "util/nls.h"
#include "ui/window.h"
#include "cpluslib/holder.h"
#include "gfx/palette.h"
#include "ui/layout.h"
#include "int/interror.h"
#include "client/labels.h"
#include "ui/msgbox.h"
#include "cpluslib/format.h"
#include "game/global.h"
#include "game/univ.h"
#include "ui/widgets/focusiterator.h"
#include "ui/widgets/statictext.h"
#include "ui/widgets/inputline.h"
#include "ui/widgets/button.h"
#include "ui/uiglobal.h"

namespace {
    class WLabelExprEditDialog : public UIWindow {
        ObjectHolder h;
        UIInputLine* input[2];

        void init();
        bool setLabel(const char* title, LabelKind kind);
     public:
        WLabelExprEditDialog();

        void onOK();
        void onCancel();
    };
}

CTASSERT(ShipLabel >= 0 && ShipLabel < 2);
CTASSERT(PlanetLabel >= 0 && PlanetLabel < 2);

WLabelExprEditDialog::WLabelExprEditDialog()
    : UIWindow(_("Ship and Planet Labels"), UIWindow::BLUE_WINDOW, COLOR_GRAY)
{
    init();
}

void
WLabelExprEditDialog::init()
{
    // VBox
    //   UIStaticText "Planets:"
    //   UIInputLine
    //   UIStaticText "Ships:"
    //   UIInputLine
    //  [UIMultilineStatic "blah blah"]
    //   UIHBox
    //     UIButton "OK"
    //     UIButton "Cancel"
    //     UISpacer
    //    [UIButton "Help"]

    setLayout(UIVBoxLayout::instance5);

    add(h.add(new UIStaticText(_("Planets:"), UIStaticText::StaticTitle)));

    input[PlanetLabel] = new UIInputLine(4096, 30, UIKey(ss_Alt + 'p'), UIInputLine::ilf_Framed, 1000);
    add(h.add(input[PlanetLabel]));

    add(h.add(new UIStaticText(_("Ships:"), UIStaticText::StaticTitle)));

    input[ShipLabel] = new UIInputLine(4096, 30, UIKey(ss_Alt + 's'), UIInputLine::ilf_Framed, 1001);
    add(h.add(input[ShipLabel]));

    UIGroup& g = h.add(new UIGroup(UIHBoxLayout::instance5));
    add(g);

    g.add(h.add(new UIButton(2000, _("OK"),     SDLK_RETURN)).addCall(this, &WLabelExprEditDialog::onOK));
    g.add(h.add(new UIButton(2001, _("Cancel"), SDLK_ESCAPE)).addCall(this, &WLabelExprEditDialog::onCancel));
    g.add(h.add(new UISpacer()));

    add(h.add(new UIFocusIterator(1000, 1001, UIFocusIterator::fi_Tab)));

    pack();

    input[PlanetLabel]->setText(getLabelExpr(PlanetLabel));
    input[ShipLabel]->setText(getLabelExpr(ShipLabel));
    input[PlanetLabel]->setFocusedWidget();
}

bool
WLabelExprEditDialog::setLabel(const char* title, LabelKind kind)
{
    try {
        setLabelExpr(kind, input[kind]->getText());
        return true;
    }
    catch (IntError& err) {
        messageBox(format(_("%s expression not accepted: %s"), title, err.what()), _("Ship and Planet Labels"));
        input[kind]->setFocusedWidget();
        getDisplayedTurn().getCurrentUniverse().sig_universe_changed.raise();
        return false;
    }
}

void
WLabelExprEditDialog::onOK()
{
    if (setLabel(_("Planet"), PlanetLabel) && setLabel(_("Ship"), ShipLabel))
        stop(1);
}

void
WLabelExprEditDialog::onCancel()
{
    stop(0);
}

void
editLabelExpressions()
{
    WLabelExprEditDialog dlg;
    ui_root->centerWidget(dlg);
    ui_root->runModal(dlg);
}
