/**
  *  \file client/tiles/visship.cc
  *  \brief Visual Scanner: Ship Information Tile
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/visship.h"
#include "util/nls.h"
#include "cpluslib/format.h"
#include "game/ship.h"
#include "game/univ.h"
#include "ui/uiglobal.h"

/************************ WVisualScanShipInfoTile ************************/

WVisualScanShipInfoTile::WVisualScanShipInfoTile(GObjectType& type)
    : WObjectTypeObserverTile(font_sizes[FONT_NORMAL].scaledBy(20, 4), type)
{ }

void
WVisualScanShipInfoTile::drawData(GfxCanvas& can)
{
    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useColorScheme(getSkin());
    ctx.useFont(*fonts[FONT_NORMAL]);
    ctx.setSolidBackground();
    ctx.setColor(UIColor::tc_Static);

    GShip* s;
    if ((s = dynamic_cast<GShip*>(getObject())) != 0) {
        const int w = extent.w;
        const int hh = font_heights[FONT_NORMAL];

        // Line 1:
        //   Mass: x kt        Speed: warp X
        //   Mass: unknown     Not moving
        string_t text;
        if (s->getMass() > 0) {
            text = format(_("Mass: %d kt"), s->getMass());
        } else {
            text = _("Mass: unknown");
        }
        outTextF(ctx, 0, 0, w/2, text);

        if (!s->getWarp().isKnown())
            text.clear();
        else if (s->getWarp() > 0)
            text = format(_("Speed: warp %d"), s->getWarp());
        else
            text = _("Not moving");
        outTextF(ctx, w/2, 0, w/2, text);

        // Line 2:
        //   Waypoint: foo
        if (s->getKind() == GShip::CurrentShip)
            text = format(_("Waypoint: %s"),
                          getType().getUniverse()->getLocationName(s->getWaypoint(), locs_WW));
        else
            text.clear();
        outTextF(ctx, 0, hh, w, text);

        // Line 3:
        //   Next turn: foo
        // FIXME: not yet implemented
        text.clear();
        outTextF(ctx, 0, 2*hh, w, text);

        // Line 4:
        //   Damage: %d%%
        if (s->getDamage().isKnown())
            text = format(_("Damage: %d%%"), s->getDamage());
        else
            text.clear();
        outTextF(ctx, 0, 3*hh, w, text);
    } else {
        // FIXME: we might show heading etc.
        drawBackground(ctx, getInnerSize(0, 0));
    }
}
