/**
  *  \file game/cargotr.h
  *  \brief Cargo Transfer
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_CARGOTR_H
#define PCC_V2_GAME_CARGOTR_H

#include "game/cargotype.h"
#include "game/transact.h"
#include "cpluslib/sigslot.h"
#include "cpluslib/ptrvector.h"
#include "game/cargo.h"

//! Cargo transfer transaction.
class GCargoTransfer : public GTransaction {
    ptr_vector<GCargoContainer> objs;
 public:
    GCargoTransfer();
    ~GCargoTransfer();

    void addNewContainer(GCargoContainer* obj)
        { objs.push_back(obj); }

    /** Get object on side.
        \param side which object you want */
    GCargoContainer& getContainer(int side)
        { return *objs[side]; }

    int32_t move(GCargoType type, int32 amount, int from, bool partial, bool s2m);
    int32_t moveFT(GCargoType type, int32 amount, int from, int32 to, bool partial, bool s2m);

    int getNumContainers() const
        { return objs.size(); }

    bool doUnload(bool s2m);

    bool isValid() const;

    GError getError();

    Signal0 sig_changed;

 protected:
    void cancel();
    void commit();
};

#endif
