/**
  *  \file game/error.cc
  *  \brief Error Messages
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include <cstring>
#include "game/error.h"

/** Standard error codes, for script side. */
const char GError::eFacility[] = "Facility not available",
    GError::eNotOwner[] = "Not owner",
    GError::eRange[] = "Range error",
    GError::ePerm[] = "Not allowed",
    GError::eNoBase[] = "No base",
    GError::eNoResource[] = "No resources",
    GError::ePos[] = "Different position",
    GError::ePartial[] = "Partial argument specification",
    GError::eUser[] = "No race loaded",
    GError::eFleet[] = "Fleet member",
    GError::eGraph[] = "Not in graphics mode",
    GError::eDone[] = "Action already performed",
    GError::eNotPlaying[] = "Race not being played";

/** Check equality.
    \param which_one error we're testing for (one of the eFoo constants).
    \return true iff this is the error we're asking for */
bool
GError::isError(const char* which_one) const
{
    return std::strcmp(which_one, script_error) == 0;
}
