/**
  *  \file ui/widgets/imagewidget.cc
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "ui/widgets/imagewidget.h"
#include "ui/util.h"
#include "gfx/palette.h"

/***************************** UIImageWidget *****************************/

/** \class UIImageWidget
    \brief Static widget displaying a pixmap */
UIImageWidget::UIImageWidget(Ptr<GfxPixmap> apix)
    : UIWidget(0), pix(apix),
      size(pix->getWidth(), pix->getHeight())
{ }

UIImageWidget::UIImageWidget(int x, int y, Ptr<GfxPixmap> pix)
    : UIWidget(0), pix(pix),
      size(x, y)
{ }

UIImageWidget::UIImageWidget(int x, int y)
    : UIWidget(0), pix(0),
      size(x, y)
{ }

void
UIImageWidget::drawContent(GfxCanvas& can)
{
    drawFrameDown(can, extent);

    // The pixmap may have transparency, but we must completely fill this widget's area.
    GfxRect r = getExtent();
    r.grow(-1, -1);
    can.drawBar(r, standard_colors[0], GFX_TRANSPARENT, SOLID_FILL, GFX_ALPHA_OPAQUE);
    if (pix) {
        pix->blitSized(can, r.x, r.y, r.w, r.h);
    }
    can.update(extent);
}

void
UIImageWidget::getLayoutInfo(LayoutInfo& info)
{
    info.pref_size = info.min_size = size;
    info.flags = 0;
}

void
UIImageWidget::setImage(Ptr<GfxPixmap> pix)
{
    this->pix = pix;
    drawWidget(false);
}

